body {
    header {
        text-align: center;

        h1 {
            a {
                text-decoration: none;
                &:visited {
                    text-decoration: none;
                }
                &:hover {
                    text-decoration: none;
                }
            }
        }
    }

    nav {
        max-width: 40rem;
        margin: 0 auto;
        text-align: center;
    }
}

ol#post-list {
  list-style: none;
  padding: 0;
  li {
    margin-bottom: 3em;
  }
}

.latex sub, .latex sup {
  text-transform: uppercase;
  font-size: 1em;
}

.latex sub {
  font-size: 1em;
}

.latex sup {
  font-size: 0.8em;
  vertical-align: 0.2em;
  margin-left: -0.42em;
  margin-right: -0.15em;
}
