{% extends "base.html" %}

{% block title %}{{ page.title }}{% endblock %}

{% block head %}
  {{ super() }}
  {% if page.keywords %}
    <meta name="keywords" content="{{page.keywords}}" />
  {% endif %}

  <meta name="description" content="{{page.summary|striptags|e}}" />

{% endblock %}

{% block content %}
    <h1>{{ page.title }}</h1>
    {% import 'translations.html' as translations with context %}
    {{ translations.translations_for(page) }}

    {{ page.content }}

{% endblock %}

